@@ -121,6 +121,7 @@ TEST(AssignFilterTest, t2)
     fo.add("assignment", "Intensity[272:] = 8");
     **/
     fo.add("value", "Intensity = 4 where Intensity <= 250");
+    fo.add("value", "Intensity = 4 where Intensity <= 250");
     fo.add("value", "Intensity = 6 where Intensity >= 245 && intensity <= 270");
     fo.add("value", "Intensity = 8 where Intensity >= 272");
 
@@ -274,3 +275,31 @@ TEST(AssignFilterTest, test_creation)
     EXPECT_EQ(l->dimType(Dimension::Id::ReturnNumber), Dimension::Type::Unsigned8);
 }
 
+TEST(AssignFilterTest, test_errors)
+{
+    auto doTest = [](const std::string expr)
+    {
+        StageFactory factory;
+
+        Stage& r = *factory.createStage("readers.las");
+        Stage& f = *factory.createStage("filters.assign");
+
+        // utm17.las contains 5 points with intensity of 280, 3 of 260 and 2 of 240
+        Options ro;
+        ro.add("filename", Support::datapath("las/utm17.las"));
+        r.setOptions(ro);
+
+        Options fo;
+        fo.add("value", expr);
+
+        f.setInput(r);
+        f.setOptions(fo);
+
+        PointTable t;
+        EXPECT_THROW(f.prepare(t), pdal_error);
+    };
+
+    doTest("X = 27 + Y FOO");
+    doTest("X = 27 & Y");
+}
+
