@@ -42,6 +42,7 @@
 #include <io/LasReader.hpp>
 #include <filters/CropFilter.hpp>
 #include <filters/ReprojectionFilter.hpp>
+#include <pdal/private/OGRSpec.hpp>
 #include <pdal/SrsBounds.hpp>
 #include <pdal/Writer.hpp>
 #include <pdal/util/FileUtils.hpp>
@@ -61,7 +62,8 @@ namespace
     const std::vector<std::string> expDimNames = {
          "X", "Y", "Z", "Intensity", "ReturnNumber", "NumberOfReturns",
          "ScanDirectionFlag", "EdgeOfFlightLine", "Classification",
-         "ScanAngleRank", "UserData", "PointSourceId", "GpsTime", "OriginId"
+         "ScanAngleRank", "UserData", "PointSourceId", "GpsTime", "OriginId", "Withheld","KeyPoint",
+         "Synthetic", "Overlap"
     };
 
     // Most of our tests will exercise this laz-based EPT dataset based on
@@ -633,8 +635,8 @@ void streamTest(const std::string src)
         return !b.compare(nodeIdDim, a) && a.compare(pointIdDim, b);
     });
 
-    normalView.stableSort(sort);
-    streamView.stableSort(sort);
+    std::sort(normalView.begin(), normalView.end(), sort);
+    std::sort(streamView.begin(), streamView.end(), sort);
 
     for (PointId i(0); i < normalView.size(); ++i)
     {
@@ -893,10 +895,12 @@ TEST(EptReaderTest, ogrCrop)
     {
         Options options;
         options.add("filename", eptAutzenPath);
-        NL::json ogr;
-        ogr["drivers"] = {"GeoJSON"};
-        ogr["datasource"] = attributesPath;
-        ogr["sql"] = "select \"_ogr_geometry_\" from attributes";
+        NL::json json;
+        json["type"] = "ogr";
+        json["drivers"] = {"GeoJSON"};
+        json["datasource"] = attributesPath;
+        json["sql"] = "select \"_ogr_geometry_\" from attributes";
+        OGRSpec ogr(json);
 
         options.add("ogr", ogr);
 
